@@ -51,12 +51,12 @@ class STFT(object):
         which FFT package to use: 'numpy' (default), 'pyfftw', or 'mkl'
     streaming : bool, optional
         whether (True, default) or not (False) to "stitch" samples between
-        repeated calls of 'analysis' and 'synthesis' if we are receiving a 
+        repeated calls of 'analysis' and 'synthesis' if we are receiving a
         continuous stream of samples.
     num_frames : int, optional
         Number of frames to be processed. If set, this will be strictly enforced
         as the STFT block will allocate memory accordingly. If not set, there
-        will be no check on the number of frames sent to 
+        will be no check on the number of frames sent to
         analysis/process/synthesis
 
         NOTE:
@@ -72,20 +72,33 @@ class STFT(object):
 
     """
 
-    def __init__(self, N, hop=None, analysis_window=None,
-                 synthesis_window=None, channels=1, transform='numpy',
-                 streaming=True, precision='double', **kwargs):
+    def __init__(
+        self,
+        N,
+        hop=None,
+        analysis_window=None,
+        synthesis_window=None,
+        channels=1,
+        transform="numpy",
+        streaming=True,
+        precision="double",
+        **kwargs
+    ):
 
         # initialize parameters
-        self.num_samples = N            # number of samples per frame
-        self.num_channels = channels    # number of channels
+        self.num_samples = N  # number of samples per frame
+        self.num_channels = channels  # number of channels
         self.mono = True if self.num_channels == 1 else False
-        if hop is not None:             # hop size --> number of input samples
-            self.hop = hop  
+        if hop is not None:  # hop size --> number of input samples
+            self.hop = hop
         else:
             self.hop = self.num_samples
 
-        if precision == np.float32 or precision == np.complex64 or precision == 'single':
+        if (
+            precision == np.float32
+            or precision == np.complex64
+            or precision == "single"
+        ):
             self.time_dtype = np.float32
             self.freq_dtype = np.complex64
         else:
@@ -98,21 +111,21 @@ class STFT(object):
 
         # prepare variables for DFT object
         self.transform = transform
-        self.nfft = self.num_samples   # differ when there is zero-padding
+        self.nfft = self.num_samples  # differ when there is zero-padding
         self.nbin = self.nfft // 2 + 1
 
         # initialize filter + zero padding --> use set_filter
         self.zf = 0
         self.zb = 0
-        self.H = None           # filter frequency spectrum
-        self.H_multi = None     # for multiple frames
+        self.H = None  # filter frequency spectrum
+        self.H_multi = None  # for multiple frames
 
         # check keywords
-        if 'num_frames' in kwargs.keys():
+        if "num_frames" in kwargs.keys():
             self.fixed_input = True
-            num_frames = kwargs['num_frames']
+            num_frames = kwargs["num_frames"]
             if num_frames < 0:
-                raise ValueError('num_frames must be non-negative!')
+                raise ValueError("num_frames must be non-negative!")
             self.num_frames = num_frames
         else:
             self.fixed_input = False
@@ -133,11 +146,13 @@ class STFT(object):
         self.n_state_out = self.nfft - self.hop
 
         # make DFT object
-        self.dft = DFT(nfft=self.nfft,
-                       D=self.num_channels,
-                       analysis_window=self.analysis_window,
-                       synthesis_window=self.synthesis_window,
-                       transform=self.transform)
+        self.dft = DFT(
+            nfft=self.nfft,
+            D=self.num_channels,
+            analysis_window=self.analysis_window,
+            synthesis_window=self.synthesis_window,
+            transform=self.transform,
+        )
         """
         1D array for num_channels=1 as the FFTW package can only take 1D array 
         for 1D DFT.
@@ -153,26 +168,30 @@ class STFT(object):
             self.out = np.zeros(self.hop, dtype=self.time_dtype)
         else:
             # input buffer
-            self.fft_in_buffer = np.zeros((self.nfft, self.num_channels),
-                                          dtype=self.time_dtype)
+            self.fft_in_buffer = np.zeros(
+                (self.nfft, self.num_channels), dtype=self.time_dtype
+            )
             # state buffer
-            self.x_p = np.zeros((self.n_state, self.num_channels),
-                                dtype=self.time_dtype)
+            self.x_p = np.zeros(
+                (self.n_state, self.num_channels), dtype=self.time_dtype
+            )
             # prev reconstructed samples
-            self.y_p = np.zeros((self.n_state_out, self.num_channels),
-                                dtype=self.time_dtype)
+            self.y_p = np.zeros(
+                (self.n_state_out, self.num_channels), dtype=self.time_dtype
+            )
             # output samples
-            self.out = np.zeros((self.hop, self.num_channels),
-                                dtype=self.time_dtype)
+            self.out = np.zeros((self.hop, self.num_channels), dtype=self.time_dtype)
 
         # useful views on the input buffer
-        self.fft_in_state = self.fft_in_buffer[self.zf:self.zf + self.n_state, ]
-        self.fresh_samples = self.fft_in_buffer[self.zf + self.n_state:
-                                                self.zf + self.n_state +
-                                                self.hop, ]
-        self.old_samples = self.fft_in_buffer[self.zf + self.hop:
-                                              self.zf + self.hop +
-                                              self.n_state, ]
+        self.fft_in_state = self.fft_in_buffer[
+            self.zf : self.zf + self.n_state,
+        ]
+        self.fresh_samples = self.fft_in_buffer[
+            self.zf + self.n_state : self.zf + self.n_state + self.hop,
+        ]
+        self.old_samples = self.fft_in_buffer[
+            self.zf + self.hop : self.zf + self.hop + self.n_state,
+        ]
 
         # if fixed number of frames to process
         if self.fixed_input:
@@ -180,19 +199,25 @@ class STFT(object):
                 if self.mono:
                     self.X = np.zeros(self.nbin, dtype=self.freq_dtype)
                 else:
-                    self.X = np.zeros((self.nbin, self.num_channels),
-                                      dtype=self.freq_dtype)
+                    self.X = np.zeros(
+                        (self.nbin, self.num_channels), dtype=self.freq_dtype
+                    )
             else:
-                self.X = np.squeeze(np.zeros((self.num_frames,
-                                              self.nbin,
-                                              self.num_channels),
-                                             dtype=self.freq_dtype))
+                self.X = np.squeeze(
+                    np.zeros(
+                        (self.num_frames, self.nbin, self.num_channels),
+                        dtype=self.freq_dtype,
+                    )
+                )
                 # DFT object for multiple frames
-                self.dft_frames = DFT(nfft=self.nfft, D=self.num_frames,
-                                      analysis_window=self.analysis_window,
-                                      synthesis_window=self.synthesis_window,
-                                      transform=self.transform)
-        else: # we will allocate these on-the-fly
+                self.dft_frames = DFT(
+                    nfft=self.nfft,
+                    D=self.num_frames,
+                    analysis_window=self.analysis_window,
+                    synthesis_window=self.synthesis_window,
+                    transform=self.transform,
+                )
+        else:  # we will allocate these on-the-fly
             self.X = None
             self.dft_frames = None
 
@@ -203,31 +228,31 @@ class STFT(object):
         """
 
         if self.mono:
-            self.fft_in_buffer[:] = 0.
-            self.x_p[:] = 0.
-            self.y_p[:] = 0.
-            self.X[:] = 0.
-            self.out[:] = 0.
+            self.fft_in_buffer[:] = 0.0
+            self.x_p[:] = 0.0
+            self.y_p[:] = 0.0
+            self.X[:] = 0.0
+            self.out[:] = 0.0
         else:
-            self.fft_in_buffer[:, :] = 0.
-            self.x_p[:, :] = 0.
-            self.y_p[:, :] = 0.
-            self.X[:, :] = 0.
-            self.out[:, :] = 0.
+            self.fft_in_buffer[:, :] = 0.0
+            self.x_p[:, :] = 0.0
+            self.y_p[:, :] = 0.0
+            self.X[:, :] = 0.0
+            self.out[:, :] = 0.0
 
     def zero_pad_front(self, zf):
         """
         Set zero-padding at beginning of frame.
         """
         self.zf = zf
-        self.nfft = self.num_samples+self.zb+self.zf
-        self.nbin = self.nfft//2+1
+        self.nfft = self.num_samples + self.zb + self.zf
+        self.nbin = self.nfft // 2 + 1
         if self.analysis_window is not None:
-            self.analysis_window = np.concatenate((np.zeros(zf),
-                                                   self.analysis_window))
+            self.analysis_window = np.concatenate((np.zeros(zf), self.analysis_window))
         if self.synthesis_window is not None:
-            self.synthesis_window = np.concatenate((np.zeros(zf),
-                                                    self.synthesis_window))
+            self.synthesis_window = np.concatenate(
+                (np.zeros(zf), self.synthesis_window)
+            )
 
         # We need to reallocate buffers after changing zero padding
         self._make_buffers()
@@ -237,14 +262,14 @@ class STFT(object):
         Set zero-padding at end of frame.
         """
         self.zb = zb
-        self.nfft = self.num_samples+self.zb+self.zf
-        self.nbin = self.nfft//2+1
+        self.nfft = self.num_samples + self.zb + self.zf
+        self.nbin = self.nfft // 2 + 1
         if self.analysis_window is not None:
-            self.analysis_window = np.concatenate((self.analysis_window,
-                                                   np.zeros(zb)))
+            self.analysis_window = np.concatenate((self.analysis_window, np.zeros(zb)))
         if self.synthesis_window is not None:
-            self.synthesis_window = np.concatenate((self.synthesis_window,
-                                                    np.zeros(zb)))
+            self.synthesis_window = np.concatenate(
+                (self.synthesis_window, np.zeros(zb))
+            )
 
         # We need to reallocate buffers after changing zero padding
         self._make_buffers()
@@ -277,15 +302,16 @@ class STFT(object):
             self.H = self.freq_dtype(np.fft.rfft(coeff, self.nfft, axis=0))
 
             # check for sufficient zero-padding
-            if self.nfft < (self.num_samples+len(coeff)-1):
-                raise ValueError('Insufficient zero-padding for chosen number '
-                                 'of samples per frame (L) and filter length '
-                                 '(h). Require zero-padding such that new '
-                                 'length is at least (L+h-1).')
+            if self.nfft < (self.num_samples + len(coeff) - 1):
+                raise ValueError(
+                    "Insufficient zero-padding for chosen number "
+                    "of samples per frame (L) and filter length "
+                    "(h). Require zero-padding such that new "
+                    "length is at least (L+h-1)."
+                )
         else:
             if len(coeff) != self.nbin:
-                raise ValueError('Invalid length for frequency domain '
-                                 'coefficients.')
+                raise ValueError("Invalid length for frequency domain " "coefficients.")
             self.H = coeff
 
         # prepare filter if fixed input case
@@ -306,35 +332,41 @@ class STFT(object):
         # ----check correct number of channels
         x_shape = x.shape
         if not self.mono:
-            if len(x_shape) < 1:   # received mono
-                raise ValueError('Received 1-channel signal. Expecting %d '
-                                 'channels.' % self.num_channels)
+            if len(x_shape) < 1:  # received mono
+                raise ValueError(
+                    "Received 1-channel signal. Expecting %d "
+                    "channels." % self.num_channels
+                )
             if x_shape[1] != self.num_channels:
-                raise ValueError('Incorrect number of channels. Received %d, '
-                                 'expecting %d.' % (x_shape[1],
-                                                    self.num_channels))
-        else:   # expecting mono
-            if len(x_shape) > 1:    # received multi-channel
-                raise ValueError('Received %d channels; expecting 1D mono '
-                                 'signal.' % x_shape[1])
+                raise ValueError(
+                    "Incorrect number of channels. Received %d, "
+                    "expecting %d." % (x_shape[1], self.num_channels)
+                )
+        else:  # expecting mono
+            if len(x_shape) > 1:  # received multi-channel
+                raise ValueError(
+                    "Received %d channels; expecting 1D mono " "signal." % x_shape[1]
+                )
 
         # ----check number of frames
         if self.streaming:  # need integer multiple of hops
 
             if self.fixed_input:
-                if x_shape[0] != self.num_frames*self.hop:
-                    raise ValueError('Input must be of length %d; received %d '
-                                     'samples.' % (self.num_frames*self.hop,
-                                                   x_shape[0]))
+                if x_shape[0] != self.num_frames * self.hop:
+                    raise ValueError(
+                        "Input must be of length %d; received %d "
+                        "samples." % (self.num_frames * self.hop, x_shape[0])
+                    )
             else:
-                self.num_frames = int(np.ceil(x_shape[0]/self.hop))
-                extra_samples = (self.num_frames*self.hop)-x_shape[0]
+                self.num_frames = int(np.ceil(x_shape[0] / self.hop))
+                extra_samples = (self.num_frames * self.hop) - x_shape[0]
                 if extra_samples:
                     if self.mono:
                         x = np.concatenate((x, np.zeros(extra_samples)))
                     else:
                         x = np.concatenate(
-                            (x, np.zeros((extra_samples, self.num_channels))))
+                            (x, np.zeros((extra_samples, self.num_channels)))
+                        )
 
         # non-streaming
         # need at least num_samples for last frame
@@ -342,12 +374,15 @@ class STFT(object):
         else:
 
             if self.fixed_input:
-                if x_shape[0] != (self.hop*(self.num_frames-1)+
-                                  self.num_samples):
-                    raise ValueError('Input must be of length %d; received %d '
-                                     'samples.' % ((self.hop*(self.num_frames-1)
-                                                    + self.num_samples),
-                                                   x_shape[0]))
+                if x_shape[0] != (self.hop * (self.num_frames - 1) + self.num_samples):
+                    raise ValueError(
+                        "Input must be of length %d; received %d "
+                        "samples."
+                        % (
+                            (self.hop * (self.num_frames - 1) + self.num_samples),
+                            x_shape[0],
+                        )
+                    )
             else:
                 if x_shape[0] < self.num_samples:
                     # raise ValueError('Not enough samples. Received %d; need \
@@ -357,34 +392,41 @@ class STFT(object):
                         x = np.concatenate((x, np.zeros(extra_samples)))
                     else:
                         x = np.concatenate(
-                            (x, np.zeros((extra_samples, self.num_channels))))
+                            (x, np.zeros((extra_samples, self.num_channels)))
+                        )
                     self.num_frames = 1
                 else:
 
                     # calculate num_frames and append zeros if necessary
-                    self.num_frames = \
-                        int(np.ceil((x_shape[0]-self.num_samples)/self.hop) + 1)
-                    extra_samples = ((self.num_frames-1)*self.hop +
-                                     self.num_samples)-x_shape[0]
+                    self.num_frames = int(
+                        np.ceil((x_shape[0] - self.num_samples) / self.hop) + 1
+                    )
+                    extra_samples = (
+                        (self.num_frames - 1) * self.hop + self.num_samples
+                    ) - x_shape[0]
                     if extra_samples:
                         if self.mono:
                             x = np.concatenate((x, np.zeros(extra_samples)))
                         else:
                             x = np.concatenate(
-                                (x,
-                                 np.zeros((extra_samples, self.num_channels))))
+                                (x, np.zeros((extra_samples, self.num_channels)))
+                            )
 
         # ----allocate memory if necessary
         if not self.fixed_input:
-            self.X = np.squeeze(np.zeros((self.num_frames,
-                                          self.nbin,
-                                          self.num_channels),
-                                         dtype=self.freq_dtype))
-            self.dft_frames = DFT(nfft=self.nfft,
-                                  D=self.num_frames,
-                                  analysis_window=self.analysis_window,
-                                  synthesis_window=self.synthesis_window,
-                                  transform=self.transform)
+            self.X = np.squeeze(
+                np.zeros(
+                    (self.num_frames, self.nbin, self.num_channels),
+                    dtype=self.freq_dtype,
+                )
+            )
+            self.dft_frames = DFT(
+                nfft=self.nfft,
+                D=self.num_frames,
+                analysis_window=self.analysis_window,
+                synthesis_window=self.synthesis_window,
+                transform=self.transform,
+            )
 
         # ----use appropriate function
         if self.streaming:
@@ -392,7 +434,7 @@ class STFT(object):
         else:
             self.reset()
             self._analysis_non_streaming(x)
-                
+
         return self.X
 
     def _analysis_single(self, x_n):
@@ -406,14 +448,20 @@ class STFT(object):
         """
 
         # correct input size check in: dft.analysis()
-        self.fresh_samples[:, ] = x_n[:, ]  # introduce new samples
-        self.x_p[:, ] = self.old_samples   # save next state
+        self.fresh_samples[:,] = x_n[
+            :,
+        ]  # introduce new samples
+        self.x_p[
+            :,
+        ] = self.old_samples  # save next state
 
         # apply DFT to current frame
         self.X[:] = self.dft.analysis(self.fft_in_buffer)
 
         # shift backwards in the buffer the state
-        self.fft_in_state[:, ] = self.x_p[:, ]
+        self.fft_in_state[:,] = self.x_p[
+            :,
+        ]
 
     def _analysis_streaming(self, x):
         """
@@ -427,15 +475,23 @@ class STFT(object):
             n = 0
             for k in range(self.num_frames):
                 # introduce new samples
-                self.fresh_samples[:, ] = x[n:n+self.hop, ]
+                self.fresh_samples[:,] = x[
+                    n : n + self.hop,
+                ]
                 # save next state
-                self.x_p[:, ] = self.old_samples
+                self.x_p[
+                    :,
+                ] = self.old_samples
 
                 # apply DFT to current frame
-                self.X[k, ] = self.dft.analysis(self.fft_in_buffer)
+                self.X[
+                    k,
+                ] = self.dft.analysis(self.fft_in_buffer)
 
                 # shift backwards in the buffer the state
-                self.fft_in_state[:, ] = self.x_p[:, ]
+                self.fft_in_state[:,] = self.x_p[
+                    :,
+                ]
 
                 n += self.hop
 
@@ -453,8 +509,13 @@ class STFT(object):
             for c in range(self.num_channels):
 
                 y = _as_strided(x[:, c], shape=new_shape, strides=new_strides)
-                y = np.concatenate((np.zeros((self.zf, self.num_frames)), y,
-                                    np.zeros((self.zb, self.num_frames))))
+                y = np.concatenate(
+                    (
+                        np.zeros((self.zf, self.num_frames)),
+                        y,
+                        np.zeros((self.zb, self.num_frames)),
+                    )
+                )
 
                 if self.num_frames == 1:
                     self.X[:, c] = self.dft_frames.analysis(y[:, 0]).T
@@ -463,8 +524,13 @@ class STFT(object):
         else:
 
             y = _as_strided(x, shape=new_shape, strides=new_strides)
-            y = np.concatenate((np.zeros((self.zf, self.num_frames)), y,
-                                np.zeros((self.zb, self.num_frames))))
+            y = np.concatenate(
+                (
+                    np.zeros((self.zf, self.num_frames)),
+                    y,
+                    np.zeros((self.zb, self.num_frames)),
+                )
+            )
 
             if self.num_frames == 1:
                 self.X[:] = self.dft_frames.analysis(y[:, 0]).T
@@ -476,7 +542,7 @@ class STFT(object):
         Ensure that given frequency data is valid, i.e. number of channels and
         number of frequency bins.
 
-        If fixed_input=True, ensure expected number of frames. Otherwise, infer 
+        If fixed_input=True, ensure expected number of frames. Otherwise, infer
         from given data.
 
         Axis order of X should be : [frames, frequencies, channels]
@@ -486,29 +552,33 @@ class STFT(object):
         X_shape = X.shape
         if len(X_shape) == 1:  # single channel, one frame
             num_frames = 1
-        elif len(X_shape) == 2 and not self.mono: # multi-channel, one frame
+        elif len(X_shape) == 2 and not self.mono:  # multi-channel, one frame
             num_frames = 1
-        elif len(X_shape) == 2 and self.mono: # single channel, multiple frames
+        elif len(X_shape) == 2 and self.mono:  # single channel, multiple frames
             num_frames = X_shape[0]
-        elif len(X_shape) == 3 and not self.mono: # multi-channel, multiple frames
+        elif len(X_shape) == 3 and not self.mono:  # multi-channel, multiple frames
             num_frames = X_shape[0]
         else:
-            raise ValueError('Invalid input shape.')
+            raise ValueError("Invalid input shape.")
 
         # check number of bins
         if num_frames == 1:
             if X_shape[0] != self.nbin:
-                raise ValueError('Invalid number of frequency bins! Expecting '
-                                 '%d, got %d.' % (self.nbin, X_shape[0]))
+                raise ValueError(
+                    "Invalid number of frequency bins! Expecting "
+                    "%d, got %d." % (self.nbin, X_shape[0])
+                )
         else:
             if X_shape[1] != self.nbin:
-                raise ValueError('Invalid number of frequency bins! Expecting'
-                                 ' %d, got %d.' % (self.nbin, X_shape[1]))
+                raise ValueError(
+                    "Invalid number of frequency bins! Expecting"
+                    " %d, got %d." % (self.nbin, X_shape[1])
+                )
 
         # check number of frames, if fixed input size
         if self.fixed_input:
             if num_frames != self.num_frames:
-                raise ValueError('Input must have %d frames!' % self.num_frames)
+                raise ValueError("Input must have %d frames!" % self.num_frames)
             self.X[:] = X  # reset if size is alright
         else:
             self.X = X
@@ -625,28 +695,32 @@ class STFT(object):
         # synthesis + overlap and add
         if not self.mono:
 
-            x_r = np.zeros((self.num_frames*self.hop, self.num_channels),
-                           dtype=self.time_dtype)
+            x_r = np.zeros(
+                (self.num_frames * self.hop, self.num_channels), dtype=self.time_dtype
+            )
 
             n = 0
             for f in range(self.num_frames):
 
                 # apply IDFT to current frame and reconstruct output
-                x_r[n:n+self.hop, ] = self._overlap_and_add(
-                    self.dft.synthesis(self.X[f, :, :]))
+                x_r[
+                    n : n + self.hop,
+                ] = self._overlap_and_add(self.dft.synthesis(self.X[f, :, :]))
                 n += self.hop
 
         else:
 
-            x_r = np.zeros(self.num_frames*self.hop, dtype=self.time_dtype)
+            x_r = np.zeros(self.num_frames * self.hop, dtype=self.time_dtype)
 
             # treat number of frames as the multiple channels for DFT
             if not self.fixed_input:
-                self.dft_frames = DFT(nfft=self.nfft,
-                                      D=self.num_frames,
-                                      analysis_window=self.analysis_window,
-                                      synthesis_window=self.synthesis_window,
-                                      transform=self.transform)
+                self.dft_frames = DFT(
+                    nfft=self.nfft,
+                    D=self.num_frames,
+                    analysis_window=self.analysis_window,
+                    synthesis_window=self.synthesis_window,
+                    transform=self.transform,
+                )
 
             # back to time domain
             mx = self.dft_frames.synthesis(self.X.T)
@@ -654,7 +728,9 @@ class STFT(object):
             # overlap and add
             n = 0
             for f in range(self.num_frames):
-                x_r[n:n+self.hop, ] = self._overlap_and_add(mx[:, f])
+                x_r[
+                    n : n + self.hop,
+                ] = self._overlap_and_add(mx[:, f])
                 n += self.hop
 
         return x_r
@@ -664,16 +740,26 @@ class STFT(object):
         if x is None:
             x = self.dft.x
 
-        self.out[:, ] = x[0:self.hop, ]  # fresh output samples
+        self.out[:,] = x[
+            0 : self.hop,
+        ]  # fresh output samples
 
         # add state from previous frames when overlap is used
         if self.n_state_out > 0:
             m = np.minimum(self.hop, self.n_state_out)
-            self.out[:m, ] += self.y_p[:m, ]
+            self.out[:m,] += self.y_p[
+                :m,
+            ]
             # update state variables
-            self.y_p[:-self.hop, ] = self.y_p[self.hop:, ]  # shift out left
-            self.y_p[-self.hop:, ] = 0.
-            self.y_p[:, ] += x[-self.n_state_out:, ]
+            self.y_p[: -self.hop,] = self.y_p[
+                self.hop :,
+            ]  # shift out left
+            self.y_p[
+                -self.hop :,
+            ] = 0.0
+            self.y_p[:,] += x[
+                -self.n_state_out :,
+            ]
 
         return self.out
 
@@ -683,6 +769,7 @@ class STFT(object):
 " ---------------------------------------------------------------------------- "
 # Authors: Robin Scheibler, Ivan Dokmanic, Sidney Barthe
 
+
 def analysis(x, L, hop, win=None, zp_back=0, zp_front=0):
     """
     Convenience function for one-shot STFT
@@ -690,7 +777,7 @@ def analysis(x, L, hop, win=None, zp_back=0, zp_front=0):
     Parameters
     ----------
     x: array_like, (n_samples) or (n_samples, n_channels)
-        input signal 
+        input signal
     L: int
         frame size
     hop: int
@@ -713,7 +800,9 @@ def analysis(x, L, hop, win=None, zp_back=0, zp_front=0):
     else:
         channels = 1
 
-    the_stft = STFT(L, hop=hop, analysis_window=win, channels=channels, precision=x.dtype)
+    the_stft = STFT(
+        L, hop=hop, analysis_window=win, channels=channels, precision=x.dtype
+    )
 
     if zp_back > 0:
         the_stft.zero_pad_back(zp_back)
@@ -756,7 +845,9 @@ def synthesis(X, L, hop, win=None, zp_back=0, zp_front=0):
     else:
         channels = 1
 
-    the_stft = STFT(L, hop=hop, synthesis_window=win, channels=channels, precision=X.dtype)
+    the_stft = STFT(
+        L, hop=hop, synthesis_window=win, channels=channels, precision=X.dtype
+    )
 
     if zp_back > 0:
         the_stft.zero_pad_back(zp_back)
@@ -798,7 +889,7 @@ def compute_synthesis_window(analysis_window, hop):
         if n == 0:
             norm += analysis_window ** 2
         elif n < 0:
-            norm[:n+L] += analysis_window[-n-L:] ** 2
+            norm[: n + L] += analysis_window[-n - L :] ** 2
         else:
             norm[n:] += analysis_window[:-n] ** 2
 
