@@ -24,6 +24,7 @@
 from __future__ import division
 
 import numpy as np
+import itertools
 from scipy import signal
 from scipy.io import wavfile
 
@@ -31,6 +32,21 @@ from .parameters import constants, eps
 from .sync import correlate
 
 
+def requires_matplotlib(func):
+    def function_wrapper(*args, **kwargs):
+        try:
+            import matplotlib.pyplot as plt
+
+            return func(*args, **kwargs)
+        except ImportError:
+            import warnings
+
+            warnings.warn("Matplotlib is required for plotting")
+            return
+
+    return function_wrapper
+
+
 def create_noisy_signal(signal_fp, snr, noise_fp=None, offset=None):
     """
     Create a noisy signal of a specified SNR.
@@ -198,7 +214,7 @@ def normalize_pwr(sig1, sig2):
 
 
 def highpass(signal, Fs, fc=None, plot=False):
-    """ Filter out the really low frequencies, default is below 50Hz """
+    """Filter out the really low frequencies, default is below 50Hz"""
 
     if fc is None:
         fc = constants.get("fc_hp")
@@ -437,19 +453,19 @@ def prony(x, p, q):
     Parameters
     ----------
 
-    x: 
+    x:
         signal to model
-    p: 
+    p:
         order of denominator
-    q: 
+    q:
         order of numerator
 
     Returns
     -------
 
-    a: 
+    a:
         numerator coefficients
-    b: 
+    b:
         denominator coefficients
     err: the squared error of approximation
     """
@@ -479,20 +495,20 @@ def shanks(x, p, q):
 
     Parameters
     ----------
-    x: 
+    x:
         signal to model
-    p: 
+    p:
         order of denominator
-    q: 
+    q:
         order of numerator
 
     Returns
     -------
-    a: 
+    a:
         numerator coefficients
-    b: 
+    b:
         denominator coefficients
-    err: 
+    err:
         the squared error of approximation
     """
 
@@ -559,7 +575,7 @@ def fractional_delay_filter_bank(delays):
     ----------
     delays: 1d narray
         The delays corresponding to each filter in fractional samples
-        
+
     Returns
     -------
     numpy array
@@ -609,9 +625,9 @@ def levinson(r, b):
 
     Parameters
     ----------
-    r: 
+    r:
         First column of R, toeplitz hermitian matrix.
-    b: 
+    b:
         The right-hand argument. If b is a matrix, the system is solved
         for every column vector in b.
 
@@ -624,7 +640,13 @@ def levinson(r, b):
     p = b.shape[0]
 
     a = np.array([1])
-    x = b[np.newaxis, 0,] / r[0]
+    x = (
+        b[
+            np.newaxis,
+            0,
+        ]
+        / r[0]
+    )
     epsilon = r[0]
 
     for j in np.arange(1, p):
@@ -636,7 +658,12 @@ def levinson(r, b):
         )
         epsilon = epsilon * (1 - np.abs(gamma) ** 2)
         delta = np.dot(np.conj(r[1 : j + 1]), np.flipud(x))
-        q = (b[j,] - delta) / epsilon
+        q = (
+            b[
+                j,
+            ]
+            - delta
+        ) / epsilon
         if len(b.shape) == 1:
             x = np.concatenate((x, np.zeros(1))) + q * np.conj(a[::-1])
         else:
@@ -725,7 +752,7 @@ def lpc(x, p, biased=True):
 
 
 def goertzel(x, k):
-    """ Goertzel algorithm to compute DFT coefficients """
+    """Goertzel algorithm to compute DFT coefficients"""
 
     N = x.shape[0]
     f = k / float(N)
@@ -738,10 +765,65 @@ def goertzel(x, k):
     return y
 
 
+def all_combinations(lst1, lst2):
+    """
+    Return all combinations between two arrays.
+    """
+    return np.array(list(itertools.product(lst1, lst2)))
+
+
 """
 GEOMETRY UTILITIES
 """
 
 
-def angle_from_points(x1, x2):
-    return np.angle((x1[0, 0] - x2[0, 0]) + 1j * (x1[1, 0] - x2[1, 0]))
+def angle_function(s1, v2):
+    """
+    Compute azimuth and colatitude angles in radians for a given set of points `s1` and a singular point `v2`.
+
+    Parameters
+    -----------
+    s1 : numpy array
+        3×N for a set of N 3-D points, 2×N for a set of N 2-D points.
+    v2 : numpy array
+        3×1 for a 3-D point, 2×1 for a 2-D point.
+
+    Returns
+    -----------
+    numpy array
+        2×N numpy array with azimuth and colatitude angles in radians.
+
+    """
+
+    if len(s1.shape) == 1:
+        s1 = s1[:, np.newaxis]
+    if len(v2.shape) == 1:
+        v2 = v2[:, np.newaxis]
+
+    assert s1.shape[0] == v2.shape[0]
+
+    x_vals = s1[0]
+    y_vals = s1[1]
+    x2 = v2[0]
+    y2 = v2[1]
+
+    # colatitude calculation for 3-D coordinates
+    if s1.shape[0] == 3 and v2.shape[0] == 3:
+
+        z2 = v2[2]
+        z_vals = s1[2]
+
+        colatitude = np.arctan2(
+            ((x_vals - x2) ** 2 + (y_vals - y2) ** 2) ** 1 / 2, (z_vals - z2)
+        )
+
+    # colatitude calculation for 2-D coordinates
+    elif s1.shape[0] == 2 and v2.shape[0] == 2:
+
+        num_points = s1.shape[1]
+        colatitude = np.ones(num_points) * np.pi / 2
+
+    # azimuth calculation (same for 2-D and 3-D)
+    azimuth = np.arctan2((y_vals - y2), (x_vals - x2))
+
+    return np.vstack((azimuth, colatitude))
